@@ -11,7 +11,7 @@
 /**
  * Moonyのバージョン
  */
-define('MOONY_VERSION', '0.10.2');
+define('MOONY_VERSION', '0.10.3');
 
 /**
  * 内部エンコーディング
@@ -137,6 +137,7 @@ define('MOONY_LOG_ROTATE', true);
 /**
  * Moonyを構成するファイルのinclude
  */
+require_once 'Moony/Cache.php';
 require_once 'Moony/Checker.php';
 require_once 'Moony/Controller.php';
 require_once 'Moony/DB.php';
@@ -189,12 +190,11 @@ class Moony
     /** @var string テンプレートファイルの右側区切り文字 */
     var $right_delimiter = '}';
 
-    /** @var array 設定ファイル名の配列 */
-    var $config_files;
+    /** @var array 設定ファイル名 */
+    var $config_file;
 
     /**
      * コンストラクタです。
-     * 必要な初期設定を行います。
      * 
      * @access public
      */
@@ -209,13 +209,10 @@ class Moony
         if (MOONY_USE_ERROR_HANDLER) {
             set_error_handler(array('Moony_Error', 'handle'));
         }
-
-        // 初期化
-        $this->config_files = array();
     }
 
     /**
-     * コントローラを起動します。
+     * 必要な初期設定を行い、コントローラを起動します。
      * 
      * @access public
      */
@@ -224,15 +221,19 @@ class Moony
         // フレームワーク情報をHTTPヘッダ出力
         header('X-Framework: Moony/' . MOONY_VERSION);
 
-        // 必須オプションチェック
+        // オプションチェック
         if (!isset($this->action_dir) ||
             !isset($this->template_dir) ||
             !isset($this->work_dir) ||
-            !isset($this->log_dir)) {
+            !isset($this->log_dir) ||
+            !isset($this->template_extension) ||
+            !isset($this->left_delimiter) ||
+            !isset($this->right_delimiter)) {
             Moony_Error::raise('Configuration failure');
         }
 
         // workディレクトリ、logディレクトリチェック
+        // ディレクトリが存在しない場合、パーミッション777で作成を試みる
         if (!Moony_Utils::isWritableDir($this->work_dir)) {
             Moony_Error::raise('Unable to write: ' . $this->work_dir);
         }
@@ -251,7 +252,7 @@ class Moony
 
         // コントローラ生成、処理開始
         $controller =& new Moony_Controller();
-        $controller->process($this->config_files);
+        $controller->process($this->config_file);
     }
 
     /**
@@ -339,39 +340,21 @@ class Moony
     }
 
     /**
-     * 設定が記述されているiniファイルを読み込みます。
+     * 設定が記述されたiniファイルを設定します。
      *
      * @access public
      * @param string $file iniァイルのパス
-     * @return boolean ファイルが存在しない場合false
+     * @return boolean ファイルが存在しない、または読み込めない場合false
      */
-    function loadConfig($file)
+    function setConfigFile($file)
     {
-        if (file_exists($file)) {
-            $this->config_files[] = $file;
+        clearstatcache();
+        if (file_exists($file) && Moony_Utils::isReadableFile($file)) {
+            $this->config_file = $file;
             return true;
         }
         return false;
     }
-
-    /**
-     * include_pathを追加します。
-     *
-     * @access public
-     * @static
-     * @param string $path include_pathに追加するパス
-     * @return boolean 追加に成功すればtrue
-     */
-    function addIncludePath($path)
-    {
-        if (file_exists($path)) {
-            $include_path = get_include_path() . PATH_SEPARATOR . $path;
-            if (set_include_path($include_path) !== false) {
-                return true;
-            }
-        }
-        return false;
-    }
 }
 
 
