@@ -35,9 +35,9 @@ class Moony_Controller
      * 無条件にアクション名に紐付くテンプレートを表示させます。
      * 
      * @access public
-     * @param array $config_files 設定ファイル名の配列
+     * @param string $config_files 設定ファイル名
      */
-    function process($config_files)
+    function process($config_file)
     {
         // アクション名決定
         $router = new Moony_Router();
@@ -45,18 +45,21 @@ class Moony_Controller
         $action_name = $router->getActionName();
         Moony_Logger::debug("Action start: $action_name");
 
+        // 設定ファイル読込
+        $settings = array();
+        if (strlen($config_file) > 0) {
+            $settings = Moony_Loader::loadIniFile($config_file);
+        }
+
         // Session生成、設定に応じて開始
         $session =& new Moony_Session();
         if (MOONY_SESSION_AUTO_START) {
             $session->start();
         }
 
-        // Request生成
+        // Request、Response生成
         $request =& new Moony_Request(&$session);
-
-        // Response生成
         $response =& new Moony_Response();
-        $response->setTemplate($action_name);
 
         // Flash生成、リストア
         $flash = new Moony_Flash(&$session);
@@ -64,45 +67,54 @@ class Moony_Controller
 
         // View生成
         $view = new Moony_View();
+        $smarty =& $view->getSmarty();
 
         // plugin登録
-        Moony_Plugins::register(&$view->smarty);
+        Moony_Plugins::register(&$smarty);
 
-        // アクション生成
-        $action = null;
-        if (Moony_Loader::loadClass($action_name, MOONY_ACTION_DIR)) {
-            // インスタンス生成
-            $action =& new $action_name;
-        } else {
-            Moony_Logger::debug("Action class not found: $action_name");
-        }
+        // アクションの処理開始
+        $on_action = true;
+        while ($on_action) {
 
-        // アクションの処理
-        if (!is_null($action)) {
+            // デフォルトテンプレート設定
+            $response->setTemplate($action_name);
+
+            // アクション生成
+            $action = null;
+            if (Moony_Loader::loadClass($action_name, MOONY_ACTION_DIR)) {
+                // インスタンス生成
+                $action =& new $action_name;
+            } else {
+                Moony_Logger::debug("Action class not found: $action_name");
+            }
+
+            if (is_null($action)) {
+                // アクションクラスが存在しない場合
+                break;
+            }
 
             // インジェクション
-            $injector =& new Moony_Injector(&$action);
-            $injector->loadAll($config_files);
+            $injector = Moony_Injector::getInstance(&$action, $settings);
             $injector->injectRequest(&$request);
             $injector->injectResponse(&$response);
             $injector->injectSession(&$session);
             $injector->injectFLash(&$flash);
-            $injector->injectSmarty(&$view->smarty);
+            $injector->injectSmarty(&$smarty);
             $injector->injectDB();
             $injector->injectUploader();
             $injector->injectOthers();
 
             // フィルタ処理
             if (method_exists($action, 'filter')) {
-                $filter =& new Moony_Filter(&$request);
+                $filter = Moony_Filter::getInstance(&$request);
                 $action->filter(&$filter);
             }
 
             // 入力値検証
             if (method_exists($action, 'validate')) {
 
-                // Validator生成
-                $validator =& new Moony_Validator(&$request);
+                // Validator取得
+                $validator = Moony_Validator::getInstance(&$request);
 
                 // 検証
                 $action->validate(&$validator);
@@ -143,24 +155,31 @@ class Moony_Controller
                 $action->execute();
             }
 
-            // 終了処理
-            $this->processEnd(&$response, &$session, &$flash);
-
-            // テキスト出力がなされていた場合、
-            // 出力して処理終了
-            if (strlen($response->getOutput()) > 0) {
-                if (!headers_sent()) {
-                    // ヘッダ送出
-                    header('Content-Type: text/plain');
-                }
-                echo $response->getOutput();
+            // 次のアクションが設定されていれば続行
+            $next_action_name = $response->getNextAction();
+            if (strlen($next_action_name) > 0) {
                 Moony_Logger::debug("Action end: $action_name");
-                exit;
+                Moony_Logger::debug("Action start continuously: $next_action_name");
+                $response->clearNextAction();
+                $action_name = $next_action_name;
+            } else {
+                $on_action = false;
             }
+        }
 
-        } else {
-            // 終了処理
-            $this->processEnd(&$response, &$session, &$flash);
+        // 終了処理
+        $this->processEnd(&$response, &$session, &$flash);
+
+        // テキスト出力がなされていた場合、
+        // 出力して処理終了
+        if (strlen($response->getOutput()) > 0) {
+            if (!headers_sent()) {
+                // ヘッダ送出
+                header('Content-Type: text/plain');
+            }
+            echo $response->getOutput();
+            Moony_Logger::debug("Action end: $action_name");
+            exit;
         }
 
         // 画面描画
