@@ -105,13 +105,12 @@ class Moony_DB
      *
      * @access public
      * @param string $sql リプレースホルダーを含むSQL
-     * @param array $params リプレースホルダーに設定するパラメータ
+     * @param array $params リプレースホルダーに設定するパラメータの配列
      * @param integer $log_level 実行SQLのログ出力レベル
      * @return integer 影響を与えたレコード数
      */
     function execute($sql, $params = null, $log_level = MOONY_LOG_LEVEL_NONE)
     {
-        $result = 0;
         Moony_Logger::log($log_level, $this->_getLog($sql, $params), __FILE__, __LINE__);
         if (isset($this->encoding) && $this->encoding != MOONY_INTERNAL_ENCODING) {
             // エンコーディングの変換
@@ -127,6 +126,41 @@ class Moony_DB
         return $this->db->affectedRows();
     }
 
+    /**
+     * Prepared Statementを利用して更新SQLを実行します。
+     * $params_arrayにはパラメータの二次元配列を指定してください。
+     * 影響を与えた全てのレコード数を結果として返します。
+     * インスタンス生成時にデータベースの文字エンコーディングが指定されている場合、
+     * パラメータのエンコーディングをデータベースの文字エンコーディングに自動的に変換します。
+     *
+     * @access public
+     * @param string $sql リプレースホルダーを含むSQL
+     * @param array $params_array リプレースホルダーに設定するパラメータの二次元配列
+     * @param integer $log_level 実行SQLのログ出力レベル
+     * @return integer 影響を与えたレコード数
+     */
+    function executeAll($sql, $params_array, $log_level = MOONY_LOG_LEVEL_NONE)
+    {
+        $count = 0;
+        if (isset($this->encoding) && $this->encoding != MOONY_INTERNAL_ENCODING) {
+            // エンコーディングの変換
+            mb_convert_variables($this->encoding, MOONY_INTERNAL_ENCODING, &$params);
+        }
+        $sth = $this->db->prepare($sql);
+        foreach ($params_array as $params) {
+            Moony_Logger::log($log_level, $this->_getLog($sql, $params), __FILE__, __LINE__);
+            $result = $this->db->execute($sth, $params);
+            if (DB::isError($result)) {
+                if ($this->in_trans) {
+                    $this->rollback();
+                }
+                Moony_Error::raise($result->getMessage(), __FILE__, __LINE__);
+            }
+            $count += $this->db->affectedRows();
+        }
+        return $count;
+    }
+
     /**
      * トランザクションを開始します。
      * AUTO COMMITをOFFに設定します。
