@@ -89,7 +89,7 @@ class Moony_Error
     function notFound()
     {
         header('HTTP/1.0 404 Not Found');
-        echo 'Not Foud';
+        echo 'Not Found';
         exit;
     }
 
