@@ -24,13 +24,29 @@ class Moony_Filter
 
     /**
      * コンストラクタです。
+     * 通常はgetInstanceを使用してください。
+     *
+     * @access private
+     */
+    function Moony_Filter()
+    {
+    }
+
+    /**
+     * このクラスのシングルトンインスタンスを取得します。
      *
      * @access public
      * @param object $request Moony_Requestのインスタンス
+     * @return object シングルトンインスタンス
      */
-    function Moony_Filter(&$request)
+    function &getInstance(&$request)
     {
-        $this->request = &$request;
+        static $instance = null;
+        if (is_null($instance)) {
+            $instance =& new Moony_Filter();
+        }
+        $instance->request = &$request;
+        return $instance;
     }
 
     /**
@@ -61,7 +77,7 @@ class Moony_Filter
      * @access public
      * @param string $name パラメータ名称
      */
-    function toFullWidthKatakana($name)
+    function toKatakana($name)
     {
         $this->convertKana($name, 'KVC');
     }
@@ -72,7 +88,7 @@ class Moony_Filter
      * @access public
      * @param string $name パラメータ名称
      */
-    function toFullWidthHiragana($name)
+    function toHiragana($name)
     {
         $this->convertKana($name, 'HVc');
     }
