@@ -127,20 +127,27 @@ class Moony_Flash
     }
 
     /**
-     * Flash変数の内容を次のアクションが実行されるまで持ち越します。
-     * $keyが指定されない場合、全てのFlash変数の内容が持ち越されます。
+     * 指定されたキーのFlash変数の内容を
+     * 次のアクションが実行されるまで持ち越します。
      *
      * @access public
      * @param string $key 持ち越すFlash変数のキー
      */
     function keep($key = null)
     {
-        if (is_null($key)) {
-            foreach ($this->stored as $key => $value) {
-                $this->set($key, $value);
-            }
-        } else {
-            $this->set($key, $this->get($key));
+        $this->set($key, $this->get($key));
+    }
+
+    /**
+     * 全てのFlash変数の内容を
+     * 次のアクションが実行されるまで持ち越します。
+     *
+     * @access public
+     */
+    function keepAll()
+    {
+        foreach ($this->stored as $key => $value) {
+            $this->set($key, $value);
         }
     }
 
