@@ -40,7 +40,7 @@ class Moony_Router
     function route()
     {
         // PATH_INFO取得
-        $path_info = Moony_Utils::getPathInfo();
+        $path_info = Moony_Utils::getEnvVar('PATH_INFO', '');
 
         // ディレクトリを指している場合、'index'を付加
         if (substr($path_info, -1) == '/') {
