@@ -70,6 +70,12 @@ class Moony_Session
     {
         if ($this->has_started) {
 
+            if (version_compare(PHP_VERSION, '5.1.0') >= 0) {
+                // session_regenerate_idが使える場合
+                session_regenerate_id(true);
+                return;
+            }
+
             $old_id = session_id();
             $path = session_save_path();
             $saved = $_SESSION;
