@@ -33,18 +33,34 @@ class Moony_Validator
 
     /**
      * コンストラクタです。
+     * 通常はgetInstanceを使用してください。
      *
-     * @access public
-     * @param object $request Moony_Requestのインスタンス
+     * @access private
      */
-    function Moony_Validator(&$request)
+    function Moony_Validator()
     {
-        $this->request = &$request;
         $this->template = null;
         $this->is_valid = true;
         $this->errors = array();
     }
 
+    /**
+     * このクラスのシングルトンインスタンスを取得します。
+     *
+     * @access public
+     * @param object $request Moony_Requestのインスタンス
+     * @return object シングルトンインスタンス
+     */
+    function &getInstance(&$request)
+    {
+        static $instance = null;
+        if (is_null($instance)) {
+            $instance =& new Moony_Validator();
+        }
+        $instance->request = &$request;
+        return $instance;
+    }
+
     /**
      * 必須項目の検証設定を行います。
      *
