@@ -61,11 +61,19 @@ class Moony_View
      */
     function render(&$response)
     {
-        // テンプレート名称
-        $template = Moony_Utils::buildPath('', $response->getTemplate(), MOONY_TEMPLATE_EXTENSION);
+        // テンプレートファイル名取得、存在チェック
+        if (($template = $this->getTemplate($response->getTemplate())) === false) {
+
+            // /fooの場合、/foo/にリダイレクトしてみる
+            $path_info = Moony_Utils::getEnvVar('PATH_INFO', '');
+            $path_info = Moony_Utils::removeFileExtension($path_info);
+            if (strlen($path_info) > 0
+                    && substr($path_info, -1, 1) != '/'
+                    && count(explode('/', trim($path_info, '/'))) < MOONY_EVAL_AS_ACTION_SETTING) {
+                $request_uri = Moony_Utils::getEnvVar('REQUEST_URI', '');
+                Moony_Utils::redirect($request_uri . '/');
+            }
 
-        // テンプレート存在チェック
-        if (!$this->smarty->template_exists($template)) {
             Moony_Logger::warn('Template file not found: ' . $template, __FILE__, __LINE__);
             Moony_Error::notFound();
         }
@@ -90,6 +98,34 @@ class Moony_View
         $this->smarty->display($template);
     }
 
+    /**
+     * Smartyのインスタンスを取得します。
+     *
+     * @access public
+     * @return object Smartyのインスタンス
+     */
+    function &getSmarty()
+    {
+        return $this->smarty;
+    }
+
+    /**
+     * 指定されたテンプレート名に拡張子を付加してテンプレートファイル名を取得します。
+     * 該当のテンプレートファイルが存在しない場合、無条件にfalseを返します。
+     *
+     * @access public
+     * @param string $template 拡張子を除いたテンプレート名称
+     * @return string|boolean テンプレートファイル名（存在しない場合、false）
+     */
+    function getTemplate($template)
+    {
+        $template = Moony_Utils::buildPath('', $template, MOONY_TEMPLATE_EXTENSION);
+        if (!$this->smarty->template_exists($template)) {
+            return false;
+        }
+        return $template;
+    }
+
     /**
      * Smartyで使用されるプリフィルタです。
      *
